@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,23 +14,25 @@
 # limitations under the License.
 #
 from collections import OrderedDict
-from distutils import util
 import os
 import re
 from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
@@ -313,6 +315,73 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[client_options_lib.ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        if client_options is None:
+            client_options = client_options_lib.ClientOptions()
+        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
+        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+        if use_client_cert not in ("true", "false"):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        if use_mtls_endpoint not in ("auto", "never", "always"):
+            raise MutualTLSChannelError(
+                "Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`"
+            )
+
+        # Figure out the client cert source to use.
+        client_cert_source = None
+        if use_client_cert == "true":
+            if client_options.client_cert_source:
+                client_cert_source = client_options.client_cert_source
+            elif mtls.has_default_client_cert_source():
+                client_cert_source = mtls.default_client_cert_source()
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        elif use_mtls_endpoint == "always" or (
+            use_mtls_endpoint == "auto" and client_cert_source
+        ):
+            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
+        else:
+            api_endpoint = cls.DEFAULT_ENDPOINT
+
+        return api_endpoint, client_cert_source
+
     def __init__(
         self,
         *,
@@ -363,50 +432,22 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
 
-        # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(
-            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
+            client_options
         )
 
-        client_cert_source_func = None
-        is_mtls = False
-        if use_client_cert:
-            if client_options.client_cert_source:
-                is_mtls = True
-                client_cert_source_func = client_options.client_cert_source
-            else:
-                is_mtls = mtls.has_default_client_cert_source()
-                if is_mtls:
-                    client_cert_source_func = mtls.default_client_cert_source()
-                else:
-                    client_cert_source_func = None
-
-        # Figure out which api endpoint to use.
-        if client_options.api_endpoint is not None:
-            api_endpoint = client_options.api_endpoint
-        else:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
-            if use_mtls_env == "never":
-                api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                if is_mtls:
-                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-                else:
-                    api_endpoint = self.DEFAULT_ENDPOINT
-            else:
-                raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
-                    "values: never, auto, always"
-                )
+        api_key_value = getattr(client_options, "api_key", None)
+        if api_key_value and credentials:
+            raise ValueError(
+                "client_options.api_key and credentials are mutually exclusive"
+            )
 
         # Save or instantiate the transport.
         # Ordinarily, we provide the transport, but allowing a custom transport
         # instance provides an extensibility point for unusual situations.
         if isinstance(transport, DataprocMetastoreTransport):
             # transport is a DataprocMetastoreTransport instance.
-            if credentials or client_options.credentials_file:
+            if credentials or client_options.credentials_file or api_key_value:
                 raise ValueError(
                     "When providing a transport instance, "
                     "provide its credentials directly."
@@ -418,6 +459,15 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
                 )
             self._transport = transport
         else:
+            import google.auth._default  # type: ignore
+
+            if api_key_value and hasattr(
+                google.auth._default, "get_api_key_credentials"
+            ):
+                credentials = google.auth._default.get_api_key_credentials(
+                    api_key_value
+                )
+
             Transport = type(self).get_transport_class(transport)
             self._transport = Transport(
                 credentials=credentials,
@@ -441,6 +491,26 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
     ) -> pagers.ListServicesPager:
         r"""Lists services in a project and location.
 
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_list_services():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.ListServicesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_services(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.ListServicesRequest, dict]):
                 The request object. Request message for
@@ -470,7 +540,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -523,6 +593,25 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
     ) -> metastore.Service:
         r"""Gets the details of a single service.
 
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_get_service():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.GetServiceRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_service(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.GetServiceRequest, dict]):
                 The request object. Request message for
@@ -549,7 +638,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -599,6 +688,31 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         r"""Creates a metastore service in a project and
         location.
 
+
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_create_service():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.CreateServiceRequest(
+                    parent="parent_value",
+                    service_id="service_id_value",
+                )
+
+                # Make the request
+                operation = client.create_service(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.CreateServiceRequest, dict]):
                 The request object. Request message for
@@ -652,7 +766,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, service, service_id])
         if request is not None and has_flattened_params:
@@ -712,6 +826,28 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
     ) -> operation.Operation:
         r"""Updates the parameters of a single service.
 
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_update_service():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.UpdateServiceRequest(
+                )
+
+                # Make the request
+                operation = client.update_service(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.UpdateServiceRequest, dict]):
                 The request object. Request message for
@@ -753,7 +889,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([service, update_mask])
         if request is not None and has_flattened_params:
@@ -812,6 +948,29 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
     ) -> operation.Operation:
         r"""Deletes a single service.
 
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_delete_service():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.DeleteServiceRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_service(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.DeleteServiceRequest, dict]):
                 The request object. Request message for
@@ -851,7 +1010,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -906,6 +1065,26 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
     ) -> pagers.ListMetadataImportsPager:
         r"""Lists imports in a service.
 
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_list_metadata_imports():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.ListMetadataImportsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_metadata_imports(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.ListMetadataImportsRequest, dict]):
                 The request object. Request message for
@@ -935,7 +1114,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -988,6 +1167,25 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
     ) -> metastore.MetadataImport:
         r"""Gets details of a single import.
 
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_get_metadata_import():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.GetMetadataImportRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_metadata_import(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.GetMetadataImportRequest, dict]):
                 The request object. Request message for
@@ -1014,7 +1212,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1064,6 +1262,31 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         r"""Creates a new MetadataImport in a given project and
         location.
 
+
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_create_metadata_import():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.CreateMetadataImportRequest(
+                    parent="parent_value",
+                    metadata_import_id="metadata_import_id_value",
+                )
+
+                # Make the request
+                operation = client.create_metadata_import(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.CreateMetadataImportRequest, dict]):
                 The request object. Request message for
@@ -1116,7 +1339,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, metadata_import, metadata_import_id])
         if request is not None and has_flattened_params:
@@ -1178,6 +1401,29 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         Only the description field of MetadataImport is
         supported to be updated.
 
+
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_update_metadata_import():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.UpdateMetadataImportRequest(
+                )
+
+                # Make the request
+                operation = client.update_metadata_import(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.UpdateMetadataImportRequest, dict]):
                 The request object. Request message for
@@ -1219,7 +1465,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([metadata_import, update_mask])
         if request is not None and has_flattened_params:
@@ -1277,6 +1523,30 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
     ) -> operation.Operation:
         r"""Exports metadata from a service.
 
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_export_metadata():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.ExportMetadataRequest(
+                    destination_gcs_folder="destination_gcs_folder_value",
+                    service="service_value",
+                )
+
+                # Make the request
+                operation = client.export_metadata(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.ExportMetadataRequest, dict]):
                 The request object. Request message for
@@ -1340,6 +1610,30 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
     ) -> operation.Operation:
         r"""Restores a service from a backup.
 
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_restore_service():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.RestoreServiceRequest(
+                    service="service_value",
+                    backup="backup_value",
+                )
+
+                # Make the request
+                operation = client.restore_service(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.RestoreServiceRequest, dict]):
                 The request object. Request message for
@@ -1378,7 +1672,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([service, backup])
         if request is not None and has_flattened_params:
@@ -1435,6 +1729,26 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
     ) -> pagers.ListBackupsPager:
         r"""Lists backups in a service.
 
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_list_backups():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.ListBackupsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_backups(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.ListBackupsRequest, dict]):
                 The request object. Request message for
@@ -1464,7 +1778,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -1517,6 +1831,25 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
     ) -> metastore.Backup:
         r"""Gets details of a single backup.
 
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_get_backup():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.GetBackupRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_backup(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.GetBackupRequest, dict]):
                 The request object. Request message for
@@ -1541,7 +1874,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
                 The details of a backup resource.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1590,6 +1923,30 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
     ) -> operation.Operation:
         r"""Creates a new backup in a given project and location.
 
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_create_backup():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.CreateBackupRequest(
+                    parent="parent_value",
+                    backup_id="backup_id_value",
+                )
+
+                # Make the request
+                operation = client.create_backup(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.CreateBackupRequest, dict]):
                 The request object. Request message for
@@ -1640,7 +1997,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, backup, backup_id])
         if request is not None and has_flattened_params:
@@ -1699,6 +2056,29 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
     ) -> operation.Operation:
         r"""Deletes a single backup.
 
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_delete_backup():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.DeleteBackupRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_backup(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.DeleteBackupRequest, dict]):
                 The request object. Request message for
@@ -1738,7 +2118,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
